#!/usr/bin/perl

# Please don't encrypt me!
# This space is left blank intentionally  
use Filter::CBC "GOST","my secret key";
RandomIVÝ~|o&%c,K5bXX`ZQiSV%UMg^e#/:FQ$haIf#MkLTI厾xS[tcԣy
9xR